@@ -33,12 +33,16 @@
 #define ANSI_COLOR_RESET     "\x1b[0m"
 
 #define color_printf(format, args...) \
-   fprintf (stdout, "\r" ANSI_COLOR_YELLOW format ANSI_COLOR_RESET "\r\n", ## args); \
-   fflush(stdout);
+   { \
+     fprintf (stdout, "\r" ANSI_COLOR_YELLOW format ANSI_COLOR_RESET "\r\n", ## args); \
+     fflush(stdout); \
+   }
 
 #define warning_printf(format, args...) \
-   fprintf (stdout, "\rWarning: " format "\r\n", ## args); \
-   fflush(stdout);
+   { \
+     fprintf (stdout, "\rWarning: " format "\r\n", ## args); \
+     fflush(stdout); \
+   }
 
 #ifdef DEBUG
 #define debug_printf(format, args...) \
